#
# spec file for package branding-openSUSE
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2019 Stasiek Michalski <hellcp@opensuse.org>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define theme_name openSUSE
%define theme_version tumbleweed
%define theme_version_clean Tumbleweed
%define date 20240405

%ifarch x86_64 %{ix86}
%define gfxboot 1
%endif

%ifarch %{arm} aarch64 %{ix86} x86_64 riscv64 ppc64le
%define grub2 1
%endif

Name:           branding-%{theme_name}
Version:        84.87.%{date}
Release:        4.4sr
Summary:        %{theme_name} %{theme_version_clean} Brand File
License:        BSD-3-Clause AND CC-BY-SA-3.0 AND GPL-2.0-or-later
URL:            https://github.com/openSUSE/branding
Source0:        branding-%{theme_version}.zip
Patch0:         test.patch
Patch1:         noTW.patch
Patch2:         Slowroll2.patch
BuildRequires:  GraphicsMagick
BuildRequires:  distribution-logos-openSUSE-Tumbleweed
BuildRequires:  fdupes
BuildRequires:  fribidi
BuildRequires:  optipng
%if 0%{?suse_version} >= 1550
# rsvg-convert used to be packaged together with rsvg-view in one package. With the removal
# of the rsvg-view program, this package was renamed to rsvg-convert (which is more fitting)
BuildRequires:  rsvg-convert
%else
BuildRequires:  rsvg-view
%endif
BuildRequires:  suse-module-tools
BuildRequires:  unzip
BuildRequires:  update-desktop-files
Conflicts:      branding
Provides:       branding
BuildArch:      noarch
%if 0%{?suse_version} > 1320
BuildRequires:  update-bootloader-rpm-macros
%endif

%description
This package contains the file %{_sysconfdir}/SUSE-brand, and its name is used as
a trigger for installation of correct vendor brand packages.

%package -n wallpaper-branding-%{theme_name}
Summary:        %{theme_name} %{theme_version_clean} default wallpapers
License:        BSD-3-Clause
Conflicts:      wallpaper-branding
Provides:       wallpaper-branding = %{version}
BuildArch:      noarch

%description -n wallpaper-branding-%{theme_name}
%{theme_name} %{theme_version_clean} defaults wallpapers

%package -n libreoffice-branding-%{theme_name}
Summary:        %{theme_name} %{theme_version_clean} branding for LibreOffice
License:        BSD-3-Clause
Supplements:    (libreoffice and branding-%{theme_name})
Conflicts:      libreoffice-branding
Provides:       libreoffice-branding = %{version}
BuildArch:      noarch

%description -n libreoffice-branding-%{theme_name}
%{theme_name} %{theme_version_clean} branding for LibreOffice

%package -n yast2-qt-branding-%{theme_name}
Summary:        %{theme_name} %{theme_version_clean} branding for YaST2 Qt
License:        BSD-3-Clause
Requires:       adobe-sourcesans3-fonts
Requires:       distribution-logos
Requires:       google-opensans-fonts
Supplements:    (libyui-qt and branding-%{theme_name})
Conflicts:      yast2-qt-branding
Provides:       yast2-qt-branding = %{version}
BuildArch:      noarch

%description -n yast2-qt-branding-%{theme_name}
%{theme_name} %{theme_version_clean} branding for YaST2 Qt, mainly used for installation

%package -n icewm-theme-yast-installation
Summary:        %{theme_name} %{theme_version_clean} branding for IceWM during the installation
License:        BSD-3-Clause AND CC-BY-SA-3.0 AND GPL-2.0-or-later
Supplements:    ((yast-installation and icewm) and branding-%{theme_name})
Conflicts:      icewm-theme-branding
BuildArch:      noarch

%description -n icewm-theme-yast-installation
This IceWM theme is specifically tailored to the %{theme_name} installation
process using YaST2

%if 0%{?grub2} > 0
%package -n grub2-branding-%{theme_name}
Summary:        %{theme_name} %{theme_version_clean} branding for GRUB2
License:        CC-BY-SA-3.0
Requires:       grub2
Supplements:    (grub2 and branding-%{theme_name})
Conflicts:      grub2-branding
Provides:       grub2-branding = %{version}
BuildArch:      noarch
%if 0%{?update_bootloader_requires:1}
%{update_bootloader_requires}
%endif

%description -n grub2-branding-%{theme_name}
%{theme_name} %{theme_version_clean} branding for the GRUB2's graphical console
%endif

%if 0%{?gfxboot} > 0
%package -n gfxboot-branding-%{theme_name}
Summary:        %{theme_name} %{theme_version_clean} branding for gfxboot
License:        BSD-3-Clause
BuildRequires:  gfxboot-devel
PreReq:         gfxboot >= 4
Requires(post): gfxboot >= 4
Supplements:    (gfxboot and branding-openSUSE)
Conflicts:      gfxboot-branding
Provides:       gfxboot-branding = %{version}
Provides:       gfxboot-theme = %{version}
BuildArch:      noarch

%description -n gfxboot-branding-%{theme_name}
%{theme_name} %{theme_version_clean} branding for gfxboot (graphical bootloader for grub).
%endif

%package -n plymouth-branding-%{theme_name}
Summary:        %{theme_name} %{theme_version_clean} branding for Plymouth bootsplash
License:        GPL-2.0-or-later
BuildRequires:  plymouth-theme-bgrt
Requires:       plymouth-scripts
Requires:       plymouth-theme-bgrt
Supplements:    (plymouth and branding-%{theme_name})
Conflicts:      plymouth-branding
Provides:       plymouth-branding = %{version}
BuildArch:      noarch

%description -n plymouth-branding-%{theme_name}
%{theme_name} %{theme_version_clean} branding for the plymouth bootsplash

%prep
%autosetup -p1 -n branding-%{theme_version}

%build
%make_build

%if 0%{?gfxboot} > 0
mkdir gfx
cp -a %{_datadir}/gfxboot/themes/openSUSE/ gfx
list=`cd openSUSE/gfxboot && find -type f`
for i in $list; do
  cp openSUSE/gfxboot/$i gfx/openSUSE/$i
done
pushd gfx/openSUSE
%if 0%{?sle_version}
  sed -i -e "s,product=.*,product=%{theme_name} %{theme_version_clean}," config
%else
  sed -i -e "s,product=.*,product=%{theme_name} %{theme_version_clean}," config
%endif
perl -pi -e 's/^(welcome=).*/${1}3/' src/gfxboot.cfg

export PATH=%{_prefix}/sbin:$PATH
make %{?_smp_mflags} BINDIR="/usr/sbin/"
popd
%endif

%install
%make_install

%if 0%{?suse_version} >= 1550
mkdir -p %{buildroot}/%{_distconfdir}
mv %{buildroot}/%{_sysconfdir}/SUSE-brand %{buildroot}/%{_distconfdir}
%endif

# gfxboot themes will soon get a make install - promised by snwint
# gfxboot should use a link /etc/bootsplash/theme -> /usr/share/bootsplash
# like splashy
if test -f gfx/openSUSE/bootlogo; then
    install -d -m 755 %{buildroot}%{_sysconfdir}/bootsplash/themes/openSUSE/{bootloader,cdrom}
    cp gfx/openSUSE/bootlogo %{buildroot}%{_sysconfdir}/bootsplash/themes/openSUSE/cdrom
    %{_datadir}/gfxboot/bin/unpack_bootlogo %{buildroot}%{_sysconfdir}/bootsplash/themes/openSUSE/cdrom
    install -m 644 gfx/openSUSE/{message,po/*.tr,help-boot/*.hlp} %{buildroot}%{_sysconfdir}/bootsplash/themes/openSUSE/bootloader
    %{_datadir}/gfxboot/bin/2hl --link --quiet %{buildroot}%{_sysconfdir}/bootsplash/themes/openSUSE/*
    touch %{buildroot}/boot/message
fi

for i in %{buildroot}%{_datadir}/wallpapers/*.desktop; do
    %suse_update_desktop_file "$i"
done

# no longer uses alternative
ln -s -f %{theme_name}-default-static.xml %{buildroot}%{_datadir}/wallpapers/%{theme_name}-default.xml

%fdupes -s %{buildroot}%{_datadir}/wallpapers/
%fdupes -s %{buildroot}%{_datadir}/YaST2/theme/current/wizard/

# compatability for binaries utilizing SLES branding (such as cockpit)
ln -s -f openSUSEdefault %{buildroot}%{_datadir}/wallpapers/SLEdefault

%if 0%{?grub2} < 1
rm -rf %{buildroot}%{_datadir}/grub2
%endif

%post -n wallpaper-branding-%{theme_name}
# remove alternative leftover
if [ $1 -gt 1 ]; then
	[ -r /etc/alternatives/%{theme_name}-default.xml ] && rm -f /etc/alternatives/%{theme_name}-default.xml || true
fi
%if 0%{?grub2} > 0
%post -n grub2-branding-%{theme_name}
%{_datadir}/grub2/themes/%{theme_name}/activate-theme
%if 0%{?update_bootloader_check_type_refresh_post:1}
%{update_bootloader_check_type_refresh_post grub2 grub2-efi}
%else
if test -e /boot/grub2/grub.cfg ; then
  %{_sbindir}/grub2-mkconfig -o /boot/grub2/grub.cfg || true
fi
%endif

%posttrans -n grub2-branding-%{theme_name}
%{?update_bootloader_posttrans}

%postun -n grub2-branding-%{theme_name}
if [ $1 = 0 ] ; then
  rm -rf /boot/grub2/themes/%{theme_name}
fi
%endif

%if 0%{?gfxboot} > 0
%post -n gfxboot-branding-%{theme_name}
gfxboot --update-theme %{theme_name}
%endif

%files
%license LICENSE
%if 0%{?suse_version} >= 1550
%{_distconfdir}/SUSE-brand
%else
%config %{_sysconfdir}/SUSE-brand
%endif

%files -n wallpaper-branding-%{theme_name}
%license LICENSE
%{_datadir}/wallpapers/openSUSE-default.xml
%dir %{_datadir}/gnome-background-properties/
%{_datadir}/gnome-background-properties/wallpaper-branding-openSUSE.xml
%{_datadir}/wallpapers/
%{_datadir}/wallpapers/SLEdefault

%files -n yast2-qt-branding-%{theme_name}
%dir %{_datadir}/YaST2
%dir %{_datadir}/YaST2/theme
%dir %{_datadir}/YaST2/theme/current
%{_datadir}/YaST2/theme/current/wizard

%files -n icewm-theme-yast-installation
%dir %{_sysconfdir}/icewm/
%config %{_sysconfdir}/icewm/theme
%dir %{_datadir}/icewm/
%dir %{_datadir}/icewm/themes/
%{_datadir}/icewm/themes/yast-installation/

%files -n libreoffice-branding-%{theme_name}
%dir %{_datadir}/libreoffice
%{_datadir}/libreoffice/program

%if 0%{?grub2} > 0
%files -n grub2-branding-%{theme_name}
%{_datadir}/grub2
%dir /boot/grub2
%dir /boot/grub2/themes
%ghost /boot/grub2/themes/%{theme_name}
%endif

%if 0%{?gfxboot} > 0
%files -n gfxboot-branding-%{theme_name}
%{_sysconfdir}/bootsplash
# Intentionally skipping over .tr files as they are hard links
%config %{_sysconfdir}/bootsplash/themes/openSUSE/bootloader/*.{hlp,jpg,mod,dat,txt,tlk,cfg,fnt}
%config %{_sysconfdir}/bootsplash/themes/openSUSE/cdrom/*.{hlp,jpg,mod,dat,txt,tlk,cfg,fnt}
%config %{_sysconfdir}/bootsplash/themes/openSUSE/cdrom/bootlogo
%{_sysconfdir}/bootsplash/themes/openSUSE/cdrom/*
%ghost /boot/message
%endif

%files -n plymouth-branding-%{theme_name}
%dir %{_datadir}/plymouth
%{_datadir}/plymouth/plymouthd.defaults

%changelog
* Thu Apr  4 2024 Lubos Kocman <lubos.kocman@suse.com>
- Use png for wallpapers for Tumbleweed
- SLES seems to be using png
- Using a compat symlink wallpapers/openSUSEdefault-> wallpapers/SLEdefault
  allows running certain apps without rebuild. Such as cockpit.
- Use optipng -o5 to compress files (has to be reflected in spec)
- Bump date
* Thu Feb 15 2024 Frederic Crozat <fcrozat@suse.com>
- Remove update-alternatives usage, we don't have dynamic
  wallpapers anymore which were using that (bsc#1219919).
* Mon Sep 25 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Enable grub2-branding on ppc64le. patterns-microos-base has
  Requires (grub2-branding-openSUSE if grub2). So we need the
  branding.
* Wed Aug 30 2023 Michael Chang <mchang@suse.com>
- Remove grub2 BuildRequires in grub2-branding (bsc#1214769)
* Mon Feb 27 2023 Jacob Michalskie <hel@lcp.world>
- Make title QToolButton backgrounds transparent
- Drop optipng requirement
* Sun Sep 19 2021 Cliff Zhao <qzhao@suse.com>
- Update branding-tumbleweed.zip from https://github.com/openSUSE/branding.git
  Drop plymouth-branding-openSUSE's watermark link add a
  configuration function to plymouth theme configuration to avoid
  logo lost which cause plymouth to fail.
- Update branding-openSUSE.spec: resort plymouth-branding-openSUSE
  install and build dependence to avoid plymouth fall to terminal
  mode in some scenario(bsc#1189613).
* Fri Sep 10 2021 Sasi Olin <hel@lcp.world>
- Drop systemd icons, since distribution-logos took that over
- Change the name of the font used in the installer
* Thu May 20 2021 Andreas Schwab <schwab@suse.de>
- Enable grub2-branding on riscv64
* Thu Apr 29 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Also skip *.tr as config files in
  /etc/bootsplash/themes/openSUSE/bootloader (in addition to
  /etc/bootsplash/themes/openSUSE/cdrom)
* Thu Mar  4 2021 Thorsten Kukuk <kukuk@suse.com>
- move SUSE-brand to /usr/etc
* Wed Jan  6 2021 Stasiek Michalski <stasiek@michalski.cc>
- Update LibreOffice About image (boo#1180550)
* Sat Sep 19 2020 Cliff Zhao <qzhao@suse.com>
- Update branding-tumbleweed.zip: Rebrand all components of SLES/D
  in boot progress (jsc#SLE-14772).
* Wed Jul 22 2020 Richard Brown <rbrown@suse.com>
- Stop building grub2-branding-openSUSE for Power architectures [boo#1171146]
* Sat Oct 26 2019 Stasiek Michalski <hellcp@mailbox.org>
- Don't set the theme on install/uninstall
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Tue Oct 15 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequires rsvg-convert instead of rsvg-view on suse_version
  >= 1550. rsvg-view no longer exists and the sub-package from
  librsvg was renamed accordingly.
* Fri Oct  4 2019 Stasiek Michalski <hellcp@mailbox.org>
- Remove symlinks for grub2
- Update requirements for distribution-logos
* Tue Oct  1 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Removed fix-parallel-build.patch - was applied upstream
- Removed xfce4-splash-branding - Splash was dropped in Xfce 4.14
* Fri Sep 13 2019 Jan Engelhardt <jengelh@inai.de>
- Avoid bashisms in scriptlets.
* Thu Aug  8 2019 Fabian Vogt <fvogt@suse.com>
- Add patch to fix parallel build:
  * fix-parallel-build.patch
* Wed Apr  3 2019 Stasiek Michalski <hellcp@mailbox.org>
- Rewrite the spec and makefile to make it easier to contibute
- Change the default plymouth theme to bgrt
* Wed Mar 13 2019 Stasiek Michalski <hellcp@mailbox.org>
- Replace font with font-size in YaST theming
* Thu Mar  7 2019 Stasiek Michalski <hellcp@mailbox.org>
- Fix systemd logo icons package
* Tue Feb 26 2019 Stefan Hundhammer <shundhammer@suse.com>
- Prevent tiny installation font (bsc#1124508)
* Tue Jan  1 2019 Stasiek Michalski <hellcp@mailbox.org>
- Add LibreOffice branding
* Fri Dec 14 2018 Stasiek Michalski <hellcp@mailbox.org>
- Slim down plymouth branding by 100kb
- Change fonts in installer to fit the branding
* Thu Nov 15 2018 Stasiek Michalski <hellcp@mailbox.org>
- Added systemd icons package before systemd 240
- Fixed issues with YaST showing wrong size of icons for partitioner
- Migrated YaST theme to using SVG images instead of PNG
* Sun Apr 29 2018 hellcp@mailbox.org
- Added 5K wallpaper
* Mon Apr 16 2018 hellcp@mailbox.org
- Don't hard-code the system role text color (bsc#1087399)
* Mon Mar 26 2018 dimstar@opensuse.org
- Update to version 15.0:
  * Better version with shadow
  * Fix wrong frame of animation
  * Fix for editable QComboBox (boo#1084816)
  * Fixed lock in plymouth
* Fri Mar 16 2018 dimstar@opensuse.org
- Fixup gfxboot/config to show 'openSUSE Tumbleweed' instead of
  'openSUSE Leap' by default (boo#1085569).
* Sat Mar 10 2018 dimstar@opensuse.org
- Update to git rev 521b8d:
  + Generate wallpapers, instead of just copying.
* Wed Mar  7 2018 dimstar@opensuse.org
- Add icewm-theme-yast-installation sub package
* Wed Mar  7 2018 dimstar@opensuse.org
- Drop kde-branding-openSUSE: Only legacy KDE 4 files
  * sysconfig.displaymanager-kdm
  * kde-branding-openSUSE.spec
  * kde-branding-openSUSE.changes
* Tue Mar  6 2018 dimstar@opensuse.org
- Update to git rev 14eaa1a:
  + Use new desktop wallpaper.
  + Updating plymouth and grub themes, xfce splash to fit new
    branding guidelines.
  + Add title properties to grub2 theme (boo#1076577).
  + Added splash image for XFCE.
  + Fixes to xfce splash, new yast theme, gfxboot.
- Sync spec file with Leap; spec-cleaned.
* Wed Jan 24 2018 dimstar@opensuse.org
- Fixup product version for Leap based on sle_version, and for
  Tumbleweed set it to 'openSUSE Tumbleweed'.
* Wed Nov  8 2017 mchang@suse.com
- Use %%posttrans for initrd creation (bsc#1066666)
* Fri Jan 20 2017 dleuenberger@suse.com
- Also require grub2 when using the new update-bootloader-rpm-macros:
  Otherwise the installer might install the branding package before
  grub2, resulting in /etc/default/grub to not exist and the theme
  failing to activate.
* Fri Jan 13 2017 mchang@suse.com
- Support %%posttrans with macros provided by update-bootloader-rpm-macros
  package (bsc#997317)
* Thu Nov 24 2016 dmueller@suse.com
- enable grub2-branding-openSUSE also for %%%%arm
* Wed Oct 19 2016 fvogt@suse.com
- Change version back to 13.3
* Tue Oct 18 2016 coolo@suse.com
- Update from git to get yast theme updates (pr#60)
* Mon Jun  6 2016 fvogt@suse.com
- Add yast2-qt-branding-openSUSE back and remove Supplements
  - Much less breakage
* Mon May 30 2016 fvogt@suse.com
- Drop yast2-qt-branding-openSUSE (boo#955381)
- Fix xfce4-splash-branding-openSUSE conflicts
* Fri Feb 19 2016 dimstar@opensuse.org
- grub2 theme: use blueish color for timeout bar.
* Tue Feb 16 2016 dimstar@opensuse.org
- Update branding with final touches.
- plymouth script: revert to single sized backround image. The
  one in the current branding deck fades out to black.
* Mon Jan  4 2016 dimstar@opensuse.org
- Update plymouth script: loading different backgrounds based on
  screen aspect ratio.
* Wed Dec 16 2015 dimstar@opensuse.org
- Update branding for Tumbleweed with new graphics.
- Reuse .spec file from Leap branding package.
* Tue Feb 17 2015 lnussel@suse.de
- enable grub theme on aarch64
* Thu Nov 13 2014 tittiatcoke@gmail.com
- Update the tarball to fix the kde-branding patches for KDE 4.14.3
* Sat Nov  8 2014 Led <ledest@gmail.com>
- fix bashisms in post/postun script
* Sat Oct 25 2014 RBrownCCB@opensuse.org
- Fix plymouth theme
- Replace Grub2 and gfxboot themes with mint on black instead of
  white on mint
* Mon Oct 13 2014 hrvoje.senjan@gmail.com
- Update KSplash for 13.2 branding
* Sat Oct 11 2014 matwey.kornilov@gmail.com
- plymouth-plugin-label is not required anymore:
  + https://github.com/openSUSE/branding/commit/e02d63e4ef11b7d9ec2e9a22326bfb83c1aba310
  + http://lists.opensuse.org/opensuse-arm/2014-10/msg00032.html
* Mon Sep  8 2014 coolo@suse.com
  update go git:
- updated KDM theme for 13.2
- reduced svg file size with Inkscape > Vacuum Defs
* Tue Sep  2 2014 coolo@suse.com
- fix merge conflicts
* Mon Sep  1 2014 rbrownccb@opensuse.org
- Lower openSUSE logo in grub2 by 5px to improve spacing under OS title
* Mon Sep  1 2014 rbrownccb@opensuse.org
- replace grub2 openSUSE logo with high resolution badge
* Mon Sep  1 2014 rbrownccb@opensuse.org
- add openSUSE logo to gfxboot images
* Mon Sep  1 2014 rbrownccb@opensuse.org
- new yast branding location now handled by git makefile, remove mv
  from spec file
* Sun Aug 31 2014 rbrownccb@opensuse.org
- Initial openSUSE 13.2 branding
* Sat Aug 30 2014 coolo@suse.com
- yast branding needs to be installed in /usr/share/YaST2/theme/current
  now
* Fri Apr 25 2014 rbrownccb@opensuse.org
- Update YaST installer look to similar to sle12
* Thu Feb 27 2014 coolo@suse.com
- set version to 13.2 - let the games begin
* Mon Oct  7 2013 bruno@ioda-net.ch
- Update for kdm : readd traditionnal username field
  fix bnc#844247 for nis login
  fix bnc#841719 clickable list again
* Tue Oct  1 2013 bruno@ioda-net.ch
- Move tarball compression to xz and save 20%% of space
- github 13.1 Makefile adapted to new tar.xz
* Mon Sep 30 2013 bruno@ioda-net.ch
- New tarball with fixes for userlist in kdm
  https://github.com/Caig/branding/commit/c0e079b539b615ae393c912ba6e6c40116926291
  bnc#842140
* Fri Sep 27 2013 coolo@suse.com
- remove workaround for bnc#782703
* Tue Sep 10 2013 tittiatcoke@gmail.com
- Add Requires(post): kdm for the kdm-branding to make sure that
  the configuration file kdmrc is installed before the branding
  is installed. This due to possible sequencing errors that could
  end up with the wrong theme for kdm.
* Tue Sep 10 2013 rbrownccb@opensuse.org
- grub2: updated release number text
* Sat Sep  7 2013 tittiatcoke@gmail.com
- Reduce the amount of KDM settings in sysconfig/displaymanager to
  purely autologin. This enables that KDM can be configured again
  through the normal KDE systemsettings module. (bnc#267903)
* Mon Sep  2 2013 sbrabec@suse.cz
- Rename branding file to SUSE-brand (FATE#316269).
* Tue Aug 27 2013 coolo@suse.com
- revert parts of fix for bnc#768686 to get installation steps
  readable again
- sync the 2 changes files with a pre_checkin.sh
* Fri Aug 16 2013 bruno@ioda-net.ch
- updated tar without gimp
* Fri Aug 16 2013 bruno@ioda-net.ch
- gimp will be unbranded in 13.1, so cleanup of gimp
* Fri Aug  2 2013 coolo@suse.com
- split kde and gimp branding into a spec file of it's own to leave
  kde out of the Factory:Core project
* Wed Jul 24 2013 hrvoje.senjan@gmail.com
- Drop kdm-branding-upstream BuildRequires, not needed since usage
  of _kde_branding_version macro
* Tue Jul  2 2013 tittiatcoke@gmail.com
- Utilize the new variable _kde_branding_version for the provides/
  requires of the KDE branding packages
* Wed Apr 24 2013 aj@suse.com
- Increase version to 13.1
* Thu Apr 18 2013 coolo@suse.com
- update from git to update kde patch
* Tue Apr  2 2013 coolo@suse.com
- add a conflict for other xfce4-splash-branding (otherproviders
  not necessary in 12.1+)
* Tue Apr  2 2013 coolo@suse.com
- fix dir conflict with grub2
* Thu Feb 28 2013 coolo@suse.com
- fix the %%post of plymouth branding to still set openSUSE default
  even if in live cd buildenv (bnc#804321)
* Fri Feb 15 2013 rbrownccb@opensuse.org
- YaST installation hyperlink color darkened
- Plymouth statup/shutdown progress fade tuned
* Thu Feb 14 2013 coolo@suse.com
- one more update for the kdm colors
* Wed Feb 13 2013 aj@suse.com
- Fix summary.
* Wed Feb 13 2013 rbrownccb@opensuse.org
- (KDM) added support for domain logins
- (KDM) changed background color of userlist box
* Mon Feb 11 2013 hrvoje.senjan@gmail.com
- Exclude upstream body-background
* Wed Feb  6 2013 rbrownccb@opensuse.org
- Final 12.3 kdelibs branding
- Tuning to kdm branding
* Wed Feb  6 2013 rbrownccb@opensuse.org
- Optimised plymouth theme file sizes
- gfxboot now using fifthleg font
- YaST2 installer theme using 12.3 green
* Tue Feb  5 2013 rbrownccb@opensuse.org
- Cleaner plymouth boot theme with fade down on shutdown
* Tue Feb  5 2013 rbrownccb@opensuse.org
- Improved Grub 2 Theme (ilmehtar & anditosan)
- Improved xfce splash (victorhck)
- Updated gfxboot backgrounds (tux93)
* Wed Jan 30 2013 rbrownccb@opensuse.org
- Grub 2 Theme based on 12.3 grow design
- gfxboot art based on 12.3 grow design
- YaST installer art based on 12.3 grow design
- xfce splash based on 12.3 grow design
- gimp splash based on 12.3 grow design
* Tue Jan 22 2013 rbrownccb@opensuse.org
- Fix Plymouth 4:3 aspect ratio so it shows vine design
* Sat Jan 19 2013 rbrownccb@opensuse.org
- Plymouth now supports several aspect ratios
* Sat Jan 19 2013 rbrownccb@opensuse.org
- Update of plymouth theme for 12.3 based on grow design
- Updated 12.3 KDM theme
* Thu Jan 10 2013 coolo@suse.com
- fix product version in gfxboot welcome screen
* Thu Jan 10 2013 coolo@suse.com
- update from git with kdm and kpslashx updates
- remove more bootsplash
* Wed Jan  9 2013 dmitry_r@opensuse.org
- Restore gfxboot welcome text
* Sat Dec 22 2012 rbrownccb@opensuse.org
- Initial 12.3 branding based on the 'grow' design
* Thu Nov 22 2012 coolo@suse.com
- bump version to 12.3 and get rid of bootsplash theming
* Sat Nov 10 2012 arvidjaar@gmail.com
- remove reference to grub2-efi-mkconfig (bnc#782891)
* Fri Sep 28 2012 coolo@suse.com
- add a /usr/share/libyui/theme symlink as long as yast looks there
  for themeing
* Sat Aug  4 2012 dmitry_r@opensuse.org
- Add new welcome text for install splash
* Fri Jul 27 2012 tittiatcoke@gmail.com
- Update to the grub2 theme to include also the theming for
  the terminal windows (bnc#770107)
* Thu Jul 26 2012 tittiatcoke@gmail.com
- Add the openSUSE branding for the Plymouth bootsplash
* Mon Jul 16 2012 snwint@suse.de
- remove /boot/grub2/backgrounds
* Thu Jul 12 2012 coolo@suse.com
- let grub2-branding supplement grub2
* Wed Jul  4 2012 mchang@suse.com
- Fix grub2 config not update on UEFI system. (bnc#770031)
* Thu Jun 28 2012 dmueller@suse.com
- make grub2 branding optional (for arm)
* Fri Jun 22 2012 snwint@suse.de
- reworked grub2 branding packages and named them grub2-branding-XXX
  (changes are in git tree)
* Sun Jun 17 2012 bruno@ioda-net.ch
- Fixed sources for grub2 (now in gitorious -art repo)
- Removed patch for grub2
* Fri Jun  8 2012 mchang@suse.com
- Add grub2-gfxconsole branding package
* Mon May 28 2012 bruno@ioda-net.ch
- Fixes for bnc#763262 kdm theme, panel is again png due to
  QSvgRender not able to handle full svg.
  Default themes is now called openSUSE in place of SUSE (also
  fixed in sysconfig/displaymanager
- Fixes for ksplash-qml-openSUSE bnc#763266 : openSUSE logo now
  stick to size in kdm for smooth transition. KDE animation position
  at better place.
* Mon May 21 2012 bruno@ioda-net.ch
- Fixes for bnc #763266 about ksplash-qml-openSUSE (bad name &
  missing file main.qml
- Fixes for bnc #763262 size of boxes and logo, background for
  users list.
* Sat May  5 2012 bruno@ioda-net.ch
- Add kdm branding for 12.2
* Tue Apr 24 2012 aj@suse.de
- Add extra license for xfce subpackage (bnc#758793).
* Sun Apr 22 2012 bruno@ioda-net.ch
- Fully updated design for 12.2
- ksplash-qml-suse added
* Tue Apr 10 2012 fisiu@opensuse.org
- Update summaries in subpackages.
* Thu Feb  9 2012 tgoettlicher@suse.de
- fix for bnc #742777: yast theme without background image
* Wed Feb  1 2012 RBrownCCB@opensuse.org
- initial update to 12.2 design
* Tue Nov 22 2011 coolo@suse.com
- bumb version
* Fri Nov 11 2011 tgoettlicher@suse.com
- fixed style of combo boxes (bnc# 725952)
* Thu Oct 27 2011 coolo@suse.com
- fix one colour code for yast
* Wed Oct 19 2011 tgoettlicher@suse.com
- fixed colors of scollbars in installation
* Sun Oct 16 2011 coolo@suse.com
- readd gimp as buildreqiures
* Thu Oct 13 2011 coolo@suse.com
- let kdm-branding provide the same version as branding-upstream
* Wed Oct 12 2011 vuntz@opensuse.org
- Change gimp-branding-openSUSE packaging to not depend on the gimp
  version, so we don't have to rebuild the package when gimp
  changes.
* Mon Oct 10 2011 coolo@suse.com
- enable kdelibs diff now
- add gimp branding
* Fri Oct  7 2011 coolo@suse.com
- add a COPYING for the xfce splash screen
* Fri Oct  7 2011 coolo@suse.com
- add branding for xfce4 splash screen
* Thu Oct  6 2011 coolo@suse.com
- prepare to patch kdelibs4 branding from upstream
* Thu Oct  6 2011 vuntz@opensuse.org
- Keep the touch required by update-alternatives here, instead of
  moving it to the Makefile.
- Move check logic to the Makefile.
* Thu Oct  6 2011 coolo@suse.com
- move install logic in the Makefile
* Wed Oct  5 2011 vuntz@opensuse.org
- Improve GNOME-related checks in %%check so that they cover the
  dynamic wallpaper and work with the new layout for static
  wallpaper.
* Wed Oct  5 2011 coolo@suse.com
- Update openSUSE.tar.gz from git:
  + More aspect ratios supported
  + Updated dynamic GNOME wallpapers
* Tue Oct  4 2011 vuntz@opensuse.org
- Update openSUSE.tar.gz from git:
  + Artwork has been updated.
  + Progress bar in bootsplash got removed since systemd doesn't
    support it.
  + Now includes the files needed for GNOME wallpapers.
- Create dynamic-wallpaper-branding-openSUSE subpackage:
  + This contains the dynamic wallpaper as used in GNOME.
  + This replaces (with appropriate Provides/Obsoletes) the
    previous openSUSE-dynamic-wallpaper package we had.
  + Install the files from the tarball needed for the dynamic
    wallpaper.
  + Use update-alternatives in %%post/%%postun of this subpackage to
    override the default wallpaper in GNOME: we prefer the dynamic
    version over the static one.
- Drop wallpaper-branding-openSUSE.xml.in and
  wallpaper-openSUSE-default-static.xml sources: they're now
  shipped openSUSE.tar.gz, so we don't have to create them.
- Move various consistency checks from %%install to %%check.
* Tue Oct  4 2011 coolo@suse.com
- provide susegreeter-branding
* Wed Sep 28 2011 coolo@suse.com
- use jpg as kdm background
* Wed Sep 28 2011 coolo@suse.com
- add kdm theme from Marcus
* Wed Sep 28 2011 coolo@suse.com
- adopt ksplashx to new logo position
* Tue Sep 27 2011 coolo@suse.com
- move ksplashx and kde wallpaper here too
* Tue Sep 27 2011 coolo@suse.com
- update bootsplash graphics
* Tue Sep 27 2011 coolo@suse.com
- fix %%ifarch logic - and update to azul previews
* Mon Sep 26 2011 vuntz@opensuse.org
- Add missing update-alternatives Requires(post)/Requires(postun)
  to wallpaper-branding-openSUSE, since this is now using
  update-alternatives.
* Fri Sep 23 2011 meissner@suse.de
- gfxboot is only on x86_64 and %%ix86
* Thu Sep 22 2011 vuntz@opensuse.org
- Import logic for the XML file used by GNOME to describe the
  default wallpaper from desktop-data-openSUSE:
  + Add wallpaper-branding-openSUSE.xml.in and
    wallpaper-openSUSE-default-static.xml source files.
  + Check in %%install that wallpaper-openSUSE-default-static.xml
    lists the right default wallpapers.
  + Use update-alternatives in %%post/%%postun of
    wallpaper-branding-openSUSE for the openSUSE-default.xml file.
- Remove unneeded GraphicsMagick, fam, inkscape and php5
  BuildRequires.
- Add update-desktop-files and call %%suse_update_desktop_file on
  the .desktop files describing the wallpapers.
* Thu Sep 22 2011 coolo@suse.com
- fix backward compat
* Thu Sep 22 2011 coolo@suse.com
- move yast2-qt branding here
* Thu Sep 22 2011 coolo@suse.com
- integrate wallpaper logic here too
* Thu Sep 22 2011 coolo@suse.com
- move details logic into art's Makefile
* Wed Sep 21 2011 coolo@suse.com
- add gfxboot branding here
* Wed Sep 21 2011 coolo@suse.com
- add bootsplash branding here
* Sat Sep 10 2011 coolo@suse.com
- bump version
* Wed Oct  6 2010 aj@suse.de
- increase version number.
* Wed Jun 23 2010 coolo@novell.com
- increase version number
* Mon Feb  9 2009 coolo@suse.de
- increase version number
* Sat Nov  1 2008 coolo@suse.de
- increase version number
* Mon Oct  6 2008 sbrabec@suse.cz
- Conflict with other branding providers (FATE#304881).
* Wed Apr  9 2008 sbrabec@suse.cz
- Added COPYING file (bnc#373602).
* Wed Mar 19 2008 sbrabec@suse.cz
- New SuSE package (fate#301464, bnc#372275).
